import os
import subprocess
import urllib.request
import argparse

from ..retriever.solr_index_docs import SolrIndex

#urls = https://www.nbcnews.com/pop-culture/davine-joy-randolph-oscar-win-best-supporting-actress-holdovers-rcna142112,https://www.nbcnews.com/news/kate-uks-princess-wales-issues-first-message-undergoing-surgery-rcna142641

def add_seed(core_name, urls):
    
    solrindex = SolrIndex(data_path=None, core=core_name)
    solr_base_url = f"http://localhost:8983/solr/{core_name}"
    json_objects = []
    
    urls = urls.split(",")
    print("type of urls: ", type(urls))
    print(urls, len(urls))
     
    for url in urls:
        data = {"url": url, "fetch_depth": 0, "status": "UNFETCHED"}
        json_objects.append(data)
    
    solrindex.index_docs(solr_base_url, json_objects)
    solrindex.commit(solr_url=solr_base_url)
        

def main():
    args = parse_args()
    add_seed(args["core"], args["urls"])

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--core", help="Give the solr core name", required=True)
    parser.add_argument("--urls", help="Give the urls name", required=True)
    args = parser.parse_args()
    return vars(args)

if __name__ == "__main__":
    main()



import os
import subprocess
import requests
import argparse

from pathlib import Path


def check_solr_status(SOLR_VERSION):
    solr_url = "http://localhost:8983/solr"
    try:
        response = requests.get(f"{solr_url}/admin/ping")
        check = response.status_code == 200
    except requests.exceptions.RequestException as e:
        print(f"Error: {e}")
        check = False

    if not check:
        subprocess.run([f"solr-{SOLR_VERSION}/bin/solr", "start"])


def change_schema(core_name, solr_dir):
    # Define the Solr base URL
    solr_base_url = f"http://localhost:8983/solr/{core_name}"

    enconf_path = solr_dir + f"/server/solr/{core_name}/conf/enumsConfig.xml"

    xml_content = """<?xml version="1.0" ?>
            <enumsConfig>
                <enum name="status">
                    <value>UNFETCHED</value>
                    <value>FETCHING</value>
                    <value>FETCHED</value>
                    <value>IGNORED</value>
                    <value>ERROR</value>
                </enum>
            </enumsConfig>"""

    with open(enconf_path, "w") as file:
        file.write(xml_content)

    # Define the field type definition
    field_type_definitions = [
        {
            "add-field-type": {
                "name": "knn_vector",
                "class": "solr.DenseVectorField",
                "vectorDimension": 1024,
                "similarityFunction": "cosine",
            }
        },
        {
            "add-field-type": {
                "name": "status",
                "class": "solr.EnumField",
                "enumsConfig": "enumsConfig.xml",
                "enumName": "status",
            }
        },
        {
            "add-field-type": {
                "name": "date",
                "class": "solr.TrieDateField",
                "docValues": True,
                "precisionStep": "0",
            }
        },
        {
            "add-field-type": {
                "name": "int",
                "class": "solr.TrieIntField",
                "docValues": True,
                "precisionStep": "0",
            }
        },
    ]

    # Define the field definition
    field_definitions = [
        {
            "add-field": {
                "name": "vector",
                "type": "knn_vector",
                "indexed": True,
                "stored": True,
            }
        },
        {
            "add-field": {
                "name": "text",
                "type": "text_en",
                "indexed": True,
                "stored": True,
            }
        },
        {
            "add-field": {
                "name": "status",
                "type": "status",
                "indexed": True,
                "stored": True,
                "default": "UNFETCHED",
                "multiValued": False,
            }
        },
        {
            "add-field": {
                "name": "outlinks",
                "type": "string",
                "indexed": False,
                "stored": True,
                "multiValued": True,
            }
        },
        {
            "add-field": {
                "name": "fetch_depth",
                "type": "int",
                "indexed": True,
                "stored": True,
                "default": "0",
            }
        },
        {
            "add-field": {
                "name": "last_crawled",
                "type": "boolean",
                "indexed": True,
                "stored": True,
            }
        },
        {
            "add-field": {
                "name": "last_updated_at",
                "type": "date",
                "indexed": True,
                "stored": True,
                "default": "NOW",
            }
        },
        {
            "add-field": {
                "name": "url",
                "type": "string",
                "indexed": True,
                "stored": True,
                "multiValued": False,
                "default": "NOW",
            }
        },
    ]

    # Update the schema with the field type
    for field_type_definition in field_type_definitions:
        response_field_type = requests.post(
            f"{solr_base_url}/schema", json=field_type_definition
        )
        if response_field_type.status_code == 200:
            print("Field type was added successfully.")
        else:
            print(
                f"Error adding field type: {response_field_type.status_code} - {response_field_type.text}"
            )

    # Add the field to the schema
    for field_definition in field_definitions:
        response_field = requests.post(f"{solr_base_url}/schema", json=field_definition)
        if response_field.status_code == 200:
            print("Field was added successfully.")
        else:
            print(
                f"Error adding field: {response_field.status_code} - {response_field.text}"
            )


def create_core(SOLR_VERSION, core_name):
    solr_dir = f"solr-{SOLR_VERSION}"
    subprocess.run([f"{solr_dir}/bin/solr", "create", "-c", core_name], check=True)

    change_schema(core_name, solr_dir)


def main():
    args = parse_args()
    SOLR_VERSION = os.getenv("SOLR_VERSION", "9.1.1")
    check_solr_status(SOLR_VERSION)
    create_core(SOLR_VERSION, (args["core"]))


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--core", help="Give the solr core name", required=True)
    args = parser.parse_args()
    return vars(args)


if __name__ == "__main__":
    main()



# input should be specific
import argparse

from pathlib import Path
from .data_pipeline.generate_embeddings import GenerateEmbeddings
from .data_pipeline.split import split_data
from .utils.data_utils import load_yaml


def main():
    args = parse_args()
    data_path = args["path"]

    conf_path = Path(__file__).parent / "confs/app.yaml"

    assert conf_path.exists(), f"{conf_path.resolve()} does not exist"

    cfg = load_yaml(conf_path)
    split_data(data_path)

    model_id = cfg["retrieval"]["gte-large"]["model_id"]

    create_embeddings = GenerateEmbeddings(model_id)
    create_embeddings.embeddings(data_path)


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--path", help="Give the path to data", required=True)
    args = parser.parse_args()
    return vars(args)


if __name__ == "__main__":
    main()



import time
import logging as log

from flask import Flask, render_template, Blueprint, request, jsonify
from nichirin.retriever.solr import SolrRetriever

app = Flask(__name__)

# Define a blueprint (optional)
bp = Blueprint("app", __name__, static_folder="static", template_folder="templates")

solr = SolrRetriever()


@bp.route("/", methods=["GET"])
def home():
    return render_template("home.html")


@bp.route("/givencontext", methods=["POST"])
def data_handeler_route():
    st = time.time()
    result = {}
    data = request.get_json(force=True)
    result = {"input": data}
    errors = []
    story = data.get("story", None)
    if isinstance(story, str):
        story = story.strip()
        if not story:
            errors.append('"context" has to be an non empty string')
    else:
        errors.append('a text field named "context" is required in input json document')
    if errors:
        result["errors"] = errors
        return result, 400
    texts = [story][0]
    try:
        response = solr.get_response(texts, "crawldb")
        # need to add core_name
        result["output"] = response
    except Exception as e:
        log.error(e, exc_info=True)
        errors.append(
            "Something went wrong with the given input. We couldnt process it."
        )
        result["errors"] = errors
        return jsonify(result), 500

    result["time"] = f"{time.time() - st:.3f}s"
    return jsonify(result)


def main():
    # Register the blueprint (optional)
    app.register_blueprint(bp)

    # Run the Flask app
    app.run(debug=True)


if __name__ == "__main__":
    main()



from pyspark.sql import SparkSession, Row
from .retriever.solr_index_docs import SolrIndex
from bs4 import BeautifulSoup
from .utils.data_utils import validate_url

import requests
import json

def fetchndump():

    solr_query = {"q": "status:UNFETCHED", "fl": "id,url,fetch_depth"}
    solr_core_url = "http://localhost:8983/solr/crawldb/select"
    response = requests.get(solr_core_url, params=solr_query)

    data = response.json()
    # depth = data["response"]["docs"]['fetch_depth']
    data = [
        (doc["url"], doc["id"], doc["fetch_depth"])
        for doc in data["response"]["docs"]
    ]
    
    return data 
 

def get_html_content(input):
    url, id, fd = input
    try:
        response = requests.get(url)
        response.raise_for_status()  # Raise an exception if the request fails
        soup = BeautifulSoup(response.text, "html.parser")

        for script in soup(["script", "style"]):
            script.extract()

        text = soup.body.get_text()

        new_urls = []

        anchor_tags = soup.find_all("a")
        for tag in anchor_tags:
            url = tag.get("href")
            if url:
                new_urls.append(url)

        new_urls = validate_url(url, new_urls)
        return new_urls, text
    
    except requests.exceptions.HTTPError as http_err:
        print(f"HTTP error occurred: {http_err}")
        return [], ""

    except requests.RequestException as e:
        print(f"Error fetching content from {url}: {e}")
        return [],""

def addfields(urls, fetch_depth):
    json_objects = []
    for url in urls:
        data = {"url": url, "fetch_depth": fetch_depth + 1, "status": "UNFETCHED"}
        json_objects.append(data)
    # FIX ME URL
    si.index_docs("http://localhost:8983/solr/crawldb/", json_objects)

def updatefields(df_batch):
    json_objects = []
    for json_string in df_batch.toJSON().collect():
        data = json.loads(json_string)

        if data["fetch_depth"] >= depth:
            data["status"] = {"set": "FETCHED"}
            continue

        text = data["text"]
        data["text"] = {"add": text}

        outlinks = data["outlinks"]

        # FIX ME
        addfields(outlinks, data["fetch_depth"])

        data["outlinks"] = {"add": outlinks}

        data["status"] = {"set": "FETCHED"}

        json_objects.append(data)
    return json_objects

def spark_rdd(urls):
    rdd = spark.sparkContext.parallelize(urls)

    # Get HTML content for each URL
    mapped_rdd = rdd.map(lambda x: (x, get_html_content(x)))
    single_partition_rdd = mapped_rdd.repartition(1)

    # print(single_partition_rdd.take(5))  # Print the first 5 elements
    # rdd is converted back to dataframe
    df_mapped = single_partition_rdd.map(
        lambda x: Row(
            url=x[0][0], id=x[0][1], fetch_depth=x[0][2], outlinks=x[1][0], text=x[1][1]
        )
    ).toDF()

    total_rows = df_mapped.count()

    si.commit(solr_url=si.solr_url)
    df_mapped.show(truncate=False)

    # Loop through the DataFrame in batches of 1000 rows
    for offset in range(0, total_rows, si.batch_size):
        df_batch = df_mapped.limit(si.batch_size).offset(offset)
        stream = updatefields(df_batch)
        si.index_docs(solr_url=si.solr_url, stream=stream)
        si.commit(solr_url=si.solr_url)


def main():
    
    #create spark session
    global si, spark, depth
    spark = SparkSession.builder.appName("URLMapOperations").getOrCreate()
    si = SolrIndex(data_path=None, core="crawldb")
    depth = 5
    
    urls = fetchndump()

    while len(urls) > 0:
        spark_rdd(urls)
        urls = fetchndump()

    spark.stop()


if __name__ == "__main__":
    main()
    



import os
import subprocess
import urllib.request


def download_and_install_solr(solr_version):
    DOWNLOAD_URL = f"https://archive.apache.org/dist/solr/solr/{solr_version}/solr-{solr_version}.tgz"

    urllib.request.urlretrieve(DOWNLOAD_URL, f"solr-{solr_version}.tgz")

    subprocess.run(["tar", "xzf", f"solr-{solr_version}.tgz"])

    print(f"Solr {solr_version} has been downloaded and installed successfully.")


def start_solr(solr_version):
    subprocess.run([f"solr-{solr_version}/bin/solr", "start"])


def main():
    SOLR_VERSION = os.getenv("SOLR_VERSION", "9.1.1")
    download_and_install_solr(SOLR_VERSION)
    start_solr(SOLR_VERSION)


if __name__ == "__main__":
    main()



import os
import argparse
import subprocess

from pathlib import Path


def partition(file_path):
    if not Path(file_path).is_file():
        print("File not found!")
        exit(1)

    directory_path = os.path.dirname(file_path)

    output_dir = Path(directory_path) / "output_dir"

    os.makedirs(output_dir)

    file_size = Path(file_path).stat().st_size

    print(f"Size of {file_path} is {file_size} bytes.")

    # if file size is lesser than 1GB then don't partition
    if file_size < 1000000000:
        subprocess.run(["mv", file_path, output_dir], check=True)
        print("File size lesser then 1 GB so did not partition")
    else:
        with open(file_path, "rb") as f:
            i = 0
            chunk = f.read(1000000000)  # read 1 GB at a time
            while chunk:
                with open(
                    os.path.join(output_dir, f"part-{i:02}.jsonl"), "wb"
                ) as f_part:
                    f_part.write(chunk)
                i += 1
                chunk = f.read(1000000000)

        print("Partitioning completed. Files are named as part-00, part-01, etc.")

        # Remove the original file
        os.remove(file_path)

        print("Original file removed.")


def main():
    args = parse_args()
    SOLR_VERSION = os.getenv("SOLR_VERSION", "9.4.0")
    partition(args["path"])


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--path", help="Give the path to data", required=True)
    args = parser.parse_args()
    return vars(args)


if __name__ == "__main__":
    main()



import torch
import argparse
import requests
from typing import List
from datetime import date
from transformers import AutoTokenizer, AutoModel
from pathlib import Path

from nichirin.utils.data_utils import load_yaml
import logging

# Use GPU if available else revert to CPU
DEVICE = torch.device("cuda" if torch.cuda.is_available() else "cpu")


class SolrRetriever:
    def __init__(self, logger=None, cfg=None) -> None:
        conf_path = Path(__file__).parent.parent / "confs/app.yaml"

        if not cfg:
            cfg = load_yaml(conf_path)
            print("cfg loaded")

        self.cfg = cfg
        self.retrieval_conf = self.cfg["retrieval"]
        self.retrieval_threshold = self.cfg["retrieval_threshold"]
        self.retrieval_top_k = self.cfg["retrieval_top_k"]

        # Load all available retrieval models separately
        self.retrieval_models = self.load_retrieval_models()
        print("Retrieval setup complete!\n")

    def load_retrieval_models(self) -> dict:
        self.retrieval_model_names = list(self.retrieval_conf.keys())

        print(
            f"Using {len(self.retrieval_model_names)} models for retrieval - {self.retrieval_model_names}"
        )

        retrieval_models = {}
        for model_name in self.retrieval_model_names:
            (
                retrieval_models[model_name + "_model"],
                retrieval_models[model_name + "_tokenizer"],
            ) = self.load_single_model(self.retrieval_conf[model_name]["model_id"])

        # Return a dict of retrieval models and tokenizers
        return retrieval_models

    def load_single_model(self, model_id: str):
        model = AutoModel.from_pretrained(model_id).to(DEVICE)
        tokenizer = AutoTokenizer.from_pretrained(model_id, model_max_length=1024)
        model = model.eval()
        torch.set_grad_enabled(False)
        print(f"Model and tokenizer for {model_id} loaded.")
        return model, tokenizer

    def mean_pooling(self, token_embeddings, mask):
        token_embeddings = token_embeddings.masked_fill(~mask[..., None].bool(), 0.0)
        sentence_embeddings = token_embeddings.sum(dim=1) / mask.sum(dim=1)[..., None]
        return sentence_embeddings

    def get_embeddings(self, text_list, model, tokenizer):
        inputs = tokenizer(
            text_list, padding=True, truncation=True, return_tensors="pt"
        ).to(DEVICE)
        outputs = model(**inputs)
        embeddings = self.mean_pooling(outputs[0], inputs["attention_mask"])
        return embeddings

    def retrieve_context(
        self, query, core_name, solr_url, model_name, char_limit=2400
    ) -> List[List[str]]:
        torch.set_grad_enabled(False)
        embed = self.get_embeddings(
            query,
            model=self.retrieval_models[f"{model_name}_model"],
            tokenizer=self.retrieval_models[f"{model_name}_tokenizer"],
        )

        vector = embed.tolist()[0]
        payload = {"query": "{!knn f=vector topK=5}" + str(vector)}
        response = requests.post(solr_url, json=payload).json()

        # Extract required field from Solr `response`
        retrieved_docs = response["response"]["docs"]
        all_docs = [
            [res_["text"], res_["score"], res_["url"], core_name]
            for res_ in retrieved_docs
        ]

        # Truncate the retrieved `text` to character limit
        for i in range(len(all_docs)):
            if all_docs[i][0] and len(all_docs[i][0]) > char_limit:
                all_docs[i][0] = all_docs[i][0][:char_limit]

        print(f"Retrieved all docs from {solr_url} using {model_name} embeddings.")
        return all_docs

    def get_response(self, query, core_name):
        # Combine the two retrieval results
        retrieved_docs = []

        # Search for relevant context using all available retrieval models
        for model_name in self.retrieval_model_names:
            print(f"Embedding query using {model_name}...")

            # Search for context in all cores for current retrieval model
            solr_url = (
                "http://localhost:8983/solr/" + core_name + "/select?fl=text,score,url"
            )

            retrieved_docs += self.retrieve_context(
                query, core_name, solr_url, model_name
            )

            print(f"Retrieved all relevant docs using {model_name}.\n")

        print(f"Total {len(retrieved_docs)} docs retrieved from solr cores.")
        # Retain only top 3 results by score and extract the text only
        reranked_retrieved_docs = sorted(
            retrieved_docs, key=lambda x: x[2], reverse=True
        )[: self.retrieval_top_k]

        # Check total token size of all retrieved_docs
        context_size = sum(len(doc[0]) for doc in reranked_retrieved_docs)
        print(
            f"Re-ranked retrieved context contains {context_size} chars or  ~{int(context_size/4)} tokens."
        )

        # Check the top score of the retrieved docs
        top_ret_score = reranked_retrieved_docs[0][1]

        if top_ret_score < self.retrieval_threshold:
            # Do not use any context from the retrieval
            retrieved_text = []
            print(
                f"Retrieved score is {top_ret_score}, which is less than {self.retrieval_threshold}. Dropping retrieved context."
            )

        else:
            retrieved_text = [(res_[0], res_[2][0]) for res_ in reranked_retrieved_docs]

        return retrieved_text


def main():
    args = parse_args()
    input_sen = args["input_sen"]
    core_name = args["core_name"]

    solr = SolrRetriever()
    response = solr.get_response(input_sen, core_name)
    print(f"Total number of responses retrived: {len(response)}")
    print(f"Retrieval result:\n{response}")


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--input_sen",
        default=str("Avenger Infinity wars movie review"),
        type=str,
        help="Input the query sentence",
    )
    parser.add_argument(
        "--core_name", type=str, help="give the core name", required=True
    )
    return vars(parser.parse_args())


if __name__ == "__main__":
    main()



import torch
import json

from pathlib import Path
from transformers import AutoTokenizer, AutoModel


class GenerateEmbeddings:
    def __init__(self, model_id):
        self.model_id = model_id
        self.device = "cuda"
        self.model = AutoModel.from_pretrained(self.model_id).to(self.device)
        self.tokenizer = AutoTokenizer.from_pretrained(self.model_id)
        self.model = self.model.eval()

    def mean_pooling(self, token_embeddings, mask):
        token_embeddings = token_embeddings.masked_fill(~mask[..., None].bool(), 0.0)
        sentence_embeddings = token_embeddings.sum(dim=1) / mask.sum(dim=1)[..., None]
        return sentence_embeddings

    def get_embeddings(self, text_list):
        inputs = self.tokenizer(
            text_list,
            padding=True,
            truncation=True,
            max_length=512,
            return_tensors="pt",
        ).to(self.device)
        outputs = self.model(**inputs)
        embeddings = self.mean_pooling(outputs[0], inputs["attention_mask"])
        return embeddings

    def embeddings(self, inp_file):
        torch.set_grad_enabled(False)
        print("Loading data from ", inp_file)

        path = Path(inp_file)
        json_files = [f for f in path.glob("*.split")]
        all_the_files = [d for d in path.iterdir()]

        embeddings = []

        for tsv_file in json_files:
            if Path(str(tsv_file) + ".pt") not in all_the_files:
                # with open(str(tsv_file) + ".tok", 'w') as output_file:
                with open(tsv_file, encoding="utf-8", errors="ignore") as dataset:
                    current_group = []
                    embeddings = []

                    for i, line in enumerate(dataset):
                        line = json.loads(line)
                        line["text"] = line["text"].replace("\n", "")
                        sen = line["text"]
                        if i % 100 == 0 and current_group:
                            embedding = self.get_embeddings(current_group)
                            embeddings.append(embedding.detach().cpu())
                            current_group = [sen]
                        else:
                            current_group.append(sen)

                    if current_group:
                        embedding = self.get_embeddings(current_group)
                        embeddings.append(embedding.detach().cpu())

                    tensor = torch.cat(embeddings)
                    embeddings = []
                    torch.save(tensor, str(tsv_file) + ".pt")



import yaml

from urllib.parse import urlparse


def load_yaml(path):
    with open(path, "r") as stream:
        return yaml.safe_load(stream)


def is_valid_url(root, url):
    # Check if a URL is valid.
    parsed_url = urlparse(url) 
    if bool(parsed_url.scheme) and bool(parsed_url.netloc):
        return url
    
    if bool(parsed_url.path) and not url.startswith(("java", "javascript")):
        return root + url
    return False


def filter_urls(root, urls):
    # Filter out unwanted URLs.
    filtered_urls = []
    for url in urls:
        output = is_valid_url(root, url) 
        if not isinstance(output, bool):
            filtered_urls.append(output)
    return filtered_urls


def validate_url(root, urls):
    filtered_urls = filter_urls(root, urls)
    return filtered_urls



#!/usr/bin/env python
import requests
import json
import time
import torch
import json
import argparse
import os

from pathlib import Path


class SolrIndex:
    # url = 'http://localhost:8983/solr/wiki/update'
    def __init__(self, data_path, core):
        self.batch_size = 1000
        self.headers = {"Content-Type": "application/json"}
        self.data_path = data_path
        self.wikidata_path = Path(self.data_path) if self.data_path else None
        self.solr_url = "http://localhost:8983/solr/" + core

    def read_(self):
        stream = self.read_docs(self.data_path)
        self.index_docs(solr_url=self.solr_url, stream=stream)
        self.commit(solr_url=self.solr_url)

    def read_docs(self, path):
        print(f"reading docs from {path}")
        skips = 0
        count = 0
        tok_file = [f for f in self.wikidata_path.glob("*.split")][0]
        ten_file = [f for f in self.wikidata_path.glob("*.pt")][0]
        tensor_exists = False

        if len(ten_file) > 0:
            tensor = torch.load(ten_file)
            tensor_exists = True

        with open(tok_file) as lines:
            for line in lines:
                data = json.load(line)
                count += 1

                if tensor_exists:
                    data["vector"] = tensor[count].tolist()

                json_string = data
                yield json_string

        print(f"Skips={skips}, Good={count}")

    def make_batches(self, stream, batch_size):
        print(f"making batches of batch={batch_size}")
        buffer = []
        for it in stream:
            buffer.append(it)
            if len(buffer) >= batch_size:
                yield buffer
                buffer = []
        if buffer:
            yield buffer

    def index_docs(self, solr_url, stream):
        print(f"indexing docs to {solr_url}")

        update_url = solr_url.rstrip("/") + "/update"

        if isinstance(stream, list):
            data = dict(add=stream)
            time.sleep(0.5)
            response = requests.post(
                update_url, headers=self.headers, data=json.dumps(data)
            )
            if response.status_code != 200:
                raise Exception(response.text)
            now_t = time.time()
        else:
            batches = self.make_batches(stream, batch_size=self.batch_size)
            count = 0
            last_t = time.time()
            for batch in batches:
                count += len(batch)
                data = dict(add=batch)
                time.sleep(0.5)
                response = requests.post(
                    update_url, headers=self.headers, data=json.dumps(data)
                )
                if response.status_code != 200:
                    raise Exception(response.text)
                now_t = time.time()
                if now_t - last_t > 2:
                    print(f"docs= {count:,}")
                    last_t = now_t
            print(f"Total docs= {count:,}")

    def commit(self, solr_url):
        print("Committing docs ")
        commit_url = solr_url.rstrip("/") + "/update"
        data = {"commit": {}}
        response = requests.post(
            commit_url, headers=self.headers, data=json.dumps(data)
        )
        print(response.status_code, response.text)
        assert response.status_code == 200


def main():
    args = parse_args()
    si = SolrIndex(args["data_path"], args["core"])
    si.read_()


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--data-path",
        type=Path,
        required=True,
        help="Give the input file path",
    )
    parser.add_argument("--core", help="Give the solr core name", required=True)
    args = parser.parse_args()
    return vars(args)


if __name__ == "__main__":
    main()



import csv
import hashlib
import nltk
import json

from pathlib import Path

nltk.download("punkt")


def parse_jsonl(file):
    with open(file, "r") as data:
        for line in data:
            line = json.loads(line)
            key = hashlib.sha256(str(line).encode()).hexdigest()
            yield line, key


def split_paragraph(paragraph):
    # sentences = re.split(r'(?<=[.!?])\s+', paragraph)
    result = []
    start = 0
    par = len(paragraph.split())

    if par < 750:
        result.append(paragraph)
        return result

    paragraph = paragraph.split()

    while start < par:
        if start + 750 > par:
            result.append(" ".join(paragraph[start:par]))
            return result
        result.append(" ".join(paragraph[start : start + 750]))  # 1st type
        start += 700

    result.append(" ".join(paragraph[start - par : par]))
    return result


def join_sentences(sentences, n):
    # Join n sentences at a time
    joined_sentences = [
        " ".join(sentences[i : i + n]) for i in range(0, len(sentences), n)
    ]
    return joined_sentences


def split_data(files_path):
    path = Path(files_path)
    clean_files = [f for f in path.glob("*.jsonl")]
    all_the_files = [d for d in path.iterdir()]

    for clean_file in clean_files:
        if Path(str(clean_file) + ".split") not in all_the_files:
            with open(str(clean_file) + ".split", "w") as output_file:
                for row, key in parse_jsonl(clean_file):
                    try:
                        row.get("url") and row.update(
                            {"url": row["url"].replace("\n", "")}
                        )
                        row["key"] = key

                        result = split_paragraph(row["text"])

                        for i, sen in enumerate(result):
                            sen = row["title"] + ":" + sen.replace("\n", "")
                            row["text"] = sen
                            output_file.write(
                                json.dumps(row, ensure_ascii=False) + "\n"
                            )

                    except:
                        print(f"skipping the line {list(row)}")
